/* This file is part of the KDE project
   Copyright (C) 2003 Joseph Wenninger <jowenn@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _KEXI_DYNAMIC_QUERY_PARAMETER_DIALOG_H_
#define _KEXI_DYNAMIC_QUERY_PARAMETER_DIALOG_H_


#include <kdialogbase.h>
#include <kexidataprovider.h>

class TQVBox;

class KexiDynamicQueryParameterDialog : public KDialogBase
{
	TQ_OBJECT
  
public:
	KexiDynamicQueryParameterDialog(TQWidget *parent,KexiDataProvider::Parameters *, const KexiDataProvider::ParameterList &);
	virtual ~KexiDynamicQueryParameterDialog();

protected:
	virtual void slotOk();
private:
//temporary only. Later a different widget will be used
	TQVBox *m_mainView;
	KexiDataProvider::Parameters *m_values;

};

#endif
